pub enum Error {
Database(Error),
Panic(JoinError),
}Expand description
An error that can occur during Oracle database connection pool operations.
Variants
Database(Error)
An error that occurred during database communication.
Panic(JoinError)
An error that occurred because a pool operation panicked.